.sql-console[data-v-a2d2c625]{display:flex;flex-direction:column;gap:16px}.button-toolbar[data-v-a2d2c625]{flex-wrap:wrap}.button-toolbar .el-button i[data-v-a2d2c625]{margin-right:8px}.editor-area[data-v-a2d2c625]{display:flex;gap:16px;height:200px}.sql-input[data-v-a2d2c625]{flex:1;min-height:100px;height:100%}.history-area[data-v-a2d2c625]{flex:1;height:198px;display:flex;background-color:var(--el-fill-color-blank);flex-direction:column}.history[data-v-a2d2c625]{flex:1;overflow-y:auto;height:120px;display:flex;flex-direction:column;gap:8px}.history-item[data-v-a2d2c625]{padding:8px 12px;border-radius:8px;background-color:var(--el-fill-color-light);cursor:pointer;word-break:break-word}@media (max-width: 384px){.editor-area[data-v-a2d2c625]{flex-direction:column;height:400px}.sql-input[data-v-a2d2c625],.history-area[data-v-a2d2c625]{width:100%;height:200px}}.affected-rows[data-v-a2d2c625]{font-weight:700;margin-bottom:10px;color:#606266}.error[data-v-a2d2c625]{color:red;margin-bottom:10px;font-weight:700}.result-card[data-v-a2d2c625]{min-height:300px;height:calc(100vh - 420px);overflow-y:auto}.pagination-wrapper[data-v-a2d2c625]{overflow-x:auto;-webkit-overflow-scrolling:touch;white-space:nowrap;width:100%}
