import{bE as E,cs as F,ct as _,cu as N,cv as v,cw as m,bG as B,cx as j,cy as C,cz as u,bA as K,bH as R,bM as H,cA as J,bJ as W,cB as Y}from"./index-DiBxRW4b.js";import{c as T,k as A,g as q,e as x,d as Q,a as V,b as X,i as Z}from"./_initCloneObject-CeJycvfb.js";function z(e,r){for(var n=-1,o=e==null?0:e.length;++n<o&&r(e[n],n,e)!==!1;);return e}function k(e,r){return e&&T(r,E(r),e)}function ee(e,r){return e&&T(r,A(r),e)}function re(e,r){return T(e,F(e),r)}var te=Object.getOwnPropertySymbols,M=te?function(e){for(var r=[];e;)N(r,F(e)),e=q(e);return r}:_;function ne(e,r){return T(e,M(e),r)}function ae(e){return v(e,A,M)}var oe=Object.prototype,ce=oe.hasOwnProperty;function se(e){var r=e.length,n=new e.constructor(r);return r&&typeof e[0]=="string"&&ce.call(e,"index")&&(n.index=e.index,n.input=e.input),n}function ie(e,r){var n=r?x(e.buffer):e.buffer;return new e.constructor(n,e.byteOffset,e.byteLength)}var be=/\w*$/;function ge(e){var r=new e.constructor(e.source,be.exec(e));return r.lastIndex=e.lastIndex,r}var w=m?m.prototype:void 0,O=w?w.valueOf:void 0;function fe(e){return O?Object(O.call(e)):{}}var ye="[object Boolean]",ue="[object Date]",Te="[object Map]",le="[object Number]",je="[object RegExp]",Ae="[object Set]",pe="[object String]",de="[object Symbol]",$e="[object ArrayBuffer]",Se="[object DataView]",me="[object Float32Array]",we="[object Float64Array]",Oe="[object Int8Array]",Ie="[object Int16Array]",he="[object Int32Array]",Ee="[object Uint8Array]",Fe="[object Uint8ClampedArray]",Be="[object Uint16Array]",Ce="[object Uint32Array]";function xe(e,r,n){var o=e.constructor;switch(r){case $e:return x(e);case ye:case ue:return new o(+e);case Se:return ie(e,n);case me:case we:case Oe:case Ie:case he:case Ee:case Fe:case Be:case Ce:return Q(e,n);case Te:return new o;case le:case pe:return new o(e);case je:return ge(e);case Ae:return new o;case de:return fe(e)}}var Me="[object Map]";function Le(e){return B(e)&&j(e)==Me}var I=u&&u.isMap,Ue=I?C(I):Le,Pe="[object Set]";function Ge(e){return B(e)&&j(e)==Pe}var h=u&&u.isSet,De=h?C(h):Ge,_e=1,Ne=2,ve=4,L="[object Arguments]",Ke="[object Array]",Re="[object Boolean]",He="[object Date]",Je="[object Error]",U="[object Function]",We="[object GeneratorFunction]",Ye="[object Map]",qe="[object Number]",P="[object Object]",Qe="[object RegExp]",Ve="[object Set]",Xe="[object String]",Ze="[object Symbol]",ze="[object WeakMap]",ke="[object ArrayBuffer]",er="[object DataView]",rr="[object Float32Array]",tr="[object Float64Array]",nr="[object Int8Array]",ar="[object Int16Array]",or="[object Int32Array]",cr="[object Uint8Array]",sr="[object Uint8ClampedArray]",ir="[object Uint16Array]",br="[object Uint32Array]",t={};t[L]=t[Ke]=t[ke]=t[er]=t[Re]=t[He]=t[rr]=t[tr]=t[nr]=t[ar]=t[or]=t[Ye]=t[qe]=t[P]=t[Qe]=t[Ve]=t[Xe]=t[Ze]=t[cr]=t[sr]=t[ir]=t[br]=!0;t[Je]=t[U]=t[ze]=!1;function l(e,r,n,o,g,c){var a,f=r&_e,y=r&Ne,G=r&ve;if(n&&(a=g?n(e,o,g,c):n(e)),a!==void 0)return a;if(!K(e))return e;var p=W(e);if(p){if(a=se(e),!f)return V(e,a)}else{var b=j(e),d=b==U||b==We;if(R(e))return X(e,f);if(b==P||b==L||d&&!g){if(a=y||d?{}:Z(e),!f)return y?ne(e,ee(a,e)):re(e,k(a,e))}else{if(!t[b])return g?e:{};a=xe(e,b,f)}}c||(c=new H);var $=c.get(e);if($)return $;c.set(e,a),De(e)?e.forEach(function(s){a.add(l(s,r,n,s,e,c))}):Ue(e)&&e.forEach(function(s,i){a.set(i,l(s,r,n,i,e,c))});var D=G?y?ae:J:y?A:E,S=p?void 0:D(e);return z(S||e,function(s,i){S&&(i=s,s=e[i]),Y(a,i,l(s,r,n,i,e,c))}),a}export{l as b,ae as g};
